Package: protGear
Type: Package
Title: Protein Micro Array Data Management and Interactive
        Visualization
Version: 1.17.0
Authors@R: c(person("Kennedy", "Mwai", role = c("cre", "aut"), email = "keniajin@gmail.com"),
             person(c("James", "Mburu"), role = "aut" , email = "mburuwanja@gmail.com") ,
             person(c("Jacqueline", "Waeni"), role = "ctb" , email = "jacqwaeni@gmail.com"))
Description: A generic three-step pre-processing package for protein microarray data. This package contains different data pre-processing procedures to allow comparison of their performance.These steps are background correction, the coefficient of variation (CV) based filtering,  batch correction and normalization.
License: GPL-3
URL: https://github.com/Keniajin/protGear
BugReports: https://github.com/Keniajin/protGear/issues
Depends: R (>= 4.2), dplyr (>= 0.8.0) , limma (>= 3.40.2) ,vsn (>=
        3.54.0)
Imports: magrittr (>= 1.5) , stats (>= 3.6) , ggplot2 (>= 3.3.0) ,
        tidyr (>= 1.1.3) , data.table (>= 1.14.0), ggpubr (>= 0.4.0),
        gtools (>= 3.8.2) , tibble (>= 3.1.0) , rmarkdown (>= 2.9) ,
        knitr (>= 1.33), utils (>= 3.6), genefilter (>= 1.74.0), readr
        (>= 2.0.1) , Biobase (>= 2.52.0), plyr (>= 1.8.6) , Kendall (>=
        2.2) , shiny (>= 1.0.0) , purrr (>= 0.3.4), plotly (>= 4.9.0) ,
        MASS (>= 7.3) , htmltools (>= 0.4.0) , flexdashboard (>= 0.5.2)
        , shinydashboard (>= 0.7.1) , GGally (>= 2.1.2) , pheatmap (>=
        1.0.12) , grid(>= 4.1.1), styler (>= 1.6.1) , factoextra (>=
        1.0.7) ,FactoMineR (>= 2.4) , rlang (>= 0.4.11), remotes (>=
        2.4.0)
Suggests: gridExtra (>= 2.3), png (>= 0.1-7) , magick (>= 2.7.3) ,
        ggplotify (>= 0.1.0) , scales (>= 1.1.1) , shinythemes (>=
        1.2.0) , shinyjs (>= 2.0.0) , shinyWidgets (>= 0.6.2) ,
        shinycssloaders (>= 1.0.0) , shinyalert (>= 3.0.0) , shinyFiles
        (>= 0.9.1) , shinyFeedback (>= 0.3.0)
biocViews: Microarray, OneChannel, Preprocessing ,
        BiomedicalInformatics , Proteomics , BatchEffect, Normalization
        , Bayesian, Clustering, Regression,SystemsBiology,
        ImmunoOncology
Encoding: UTF-8
RoxygenNote: 7.2.3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/protGear
git_branch: devel
git_last_commit: d855f9b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:28:06 UTC; biocbuild
Author: Kennedy Mwai [cre, aut],
  James Mburu [aut],
  Jacqueline Waeni [ctb]
Maintainer: Kennedy Mwai <keniajin@gmail.com>
