# Generated by roxygen2: do not edit by hand

export(array_vars)
export(best_CV_estimation)
export(bg_correct)
export(buffer_spots)
export(check_sampleID_files)
export(create_dir)
export(cv_by_sample_estimation)
export(cv_estimation)
export(extract_bg)
export(launch_protGear_interactive)
export(launch_select)
export(matrix_normalise)
export(merge_sampleID)
export(minpositive)
export(name_of_files)
export(output_trend_stats)
export(plot_FB)
export(plot_bg)
export(plot_buffer)
export(plot_normalised)
export(plot_normalised_antigen)
export(read_array_files)
export(read_array_visualize)
export(rlm_normalise)
export(rlm_normalise_matrix)
export(tag_subtract)
export(visualize_slide)
export(visualize_slide_2d)
import(FactoMineR)
import(GGally)
import(dplyr)
import(factoextra)
import(ggplot2)
import(ggpubr)
import(grid)
import(htmltools)
import(knitr)
import(limma)
import(pheatmap)
import(remotes)
import(rmarkdown)
import(shiny)
import(styler)
import(tibble)
import(tidyr)
import(vsn)
importFrom(Kendall,MannKendall)
importFrom(data.table,"%like%")
importFrom(data.table,fread)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_rows)
importFrom(dplyr,lag)
importFrom(dplyr,last)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(flexdashboard,renderValueBox)
importFrom(flexdashboard,valueBox)
importFrom(flexdashboard,valueBoxOutput)
importFrom(genefilter,rowSds)
importFrom(ggplot2,ggplot)
importFrom(gtools,mixedsort)
importFrom(magrittr,"%>%")
importFrom(plotly,ggplotly)
importFrom(plyr,.)
importFrom(purrr,set_names)
importFrom(readr,read_csv)
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,UQ)
importFrom(rlang,parse_expr)
importFrom(rlang,sym)
importFrom(shinydashboard,renderInfoBox)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(utils,read.csv)
importFrom(utils,write.table)
