---
title: "protGear: Protein micro array data management suite"
output:
  flexdashboard::flex_dashboard:
  theme: cosmo
orientation: rows
vertical_layout: scroll
runtime: shiny
---



```{r setup, include=FALSE}
## Inside the working directory create a sampleID folder to contain information of the sampleIDs
## they should be named according to the sampleID names
library(ggpubr)
library(limma)
library(vsn)
library(ggpubr)
library(gtools)
library(plotly)
library(shinythemes)
library(shinyjs)
library(shinyWidgets)
library(GGally)
library(DT)
library(shinycssloaders)
library(gridExtra)
library(pheatmap)
library(scales)
library(shinyFeedback)
library(shinyalert)
library(data.table)
library(stringr)
library(trend)
library(flexdashboard)
library(shiny)
library(factoextra)
library(shinyFiles)

#### save all the files as objects
#Increasing the default maximum upload restriction of Shiny to 10GB can add to globally
if(Sys.getenv('SHINY_PORT') == "") options(shiny.maxRequestSize=10000*1024^2)


jsToggleFS <- 'shinyjs.toggleFullScreen = function() {
    var element = document.documentElement,
      enterFS = element.requestFullscreen || element.msRequestFullscreen || element.mozRequestFullScreen || element.webkitRequestFullscreen,
      exitFS = document.exitFullscreen || document.msExitFullscreen || document.mozCancelFullScreen || document.webkitExitFullscreen;
    if (!document.fullscreenElement && !document.msFullscreenElement && !document.mozFullScreenElement && !document.webkitFullscreenElement) {
      enterFS.call(element);
    } else {
      exitFS.call(document);
    }
  }'

#useShinyjs(),
#extendShinyjs(text = jsToggleFS)
```


Data Processing {data-width=300}
======================================================================

```{r, height = "100vh"}
dir_app <- system.file("shiny-examples/protGear_interactive/load_data_dashboard/", package = "protGear")
fluidRow(class="sidebarItemExpanded",
    column(12,div(style = "height: 100vh;margin:0,padding:0;",
shinyAppDir(dir_app, options = list(width = "100%", height = "100vh"))
)))
```



About protGear {data-width=300}
======================================================================
 

```{r, height = "100%"}
about_dir_app <- system.file("shiny-examples/protGear_interactive/about_app/", package = "protGear")
fluidRow(
    column(12,div(style = "height:1000px;background-color: white;margin: 0;padding: 0;",
shinyAppDir(about_dir_app, options = list(width = "100%", height = "100%"))
)))
```


Help 
======

```{r}
dropdownMenu(type = "notifications",headerText = strong("HELP"), 
                                          icon = icon("question"), 
                                          badgeStatus = NULL,
                                          notificationItem(
                                            text = (steps$text[1]),
                                            icon = icon("spinner")
                                          ),
                                          notificationItem(
                                            text = steps$text[2],
                                            icon = icon("address-card")
                                          ),
                                          notificationItem(
                                            text = steps$text[3],
                                            icon = icon("calendar")
                                          ),
                                          notificationItem(
                                            text = steps$text[4],
                                            icon = icon("user-md")
                                          ),
                                          notificationItem(
                                            text = steps$text[5],
                                            icon = icon("ambulance")
                                          ),
                                          notificationItem(
                                            text = steps$text[6],
                                            icon = icon("flask")
                                          ),
                                          notificationItem(
                                            text = strong(steps$text[7]),
                                            icon = icon("exclamation")
                                          )  )
```

