% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_files_functions.R
\name{visualize_slide}
\alias{visualize_slide}
\title{Visualize the slide mimicking the original scan image.}
\usage{
visualize_slide(infile, MFI_var, interactive = FALSE, d_f = NA)
}
\arguments{
\item{infile}{a .gpr file to be used to visualize the expression 
intensities of the slide spots}

\item{MFI_var}{the MFI variable to plot, can be either the
background or foreground value}

\item{interactive}{a logical to specify whether an interactive 
graph is returned or not}

\item{d_f}{a data frame with array data}
}
\value{
A ggplot of slide foreground values
}
\description{
Visualize the slide mimicking the original scan image.
}
\examples{
## Not run:
visualize_slide(
infile = system.file("extdata", "/array_data/machine1/KK2-06.txt",
 package="protGear"),
MFI_var = "B635 Median"
)
## End(Not run)
}
